import { ALERT_SEVERITY } from './alert/severity.mts';
import type { ALERT_ACTION, CompactSocketArtifact, CompactSocketArtifactAlert } from './alert/artifact.mts';
import type { Spinner } from '@socketsecurity/registry/lib/spinner';
export declare const ALERT_SEVERITY_COLOR: Readonly<{
    readonly critical: "magenta";
    readonly high: "red";
    readonly middle: "yellow";
    readonly low: "white";
}>;
export declare const ALERT_SEVERITY_ORDER: Readonly<{
    readonly critical: 0;
    readonly high: 1;
    readonly middle: 2;
    readonly low: 3;
    readonly none: 4;
}>;
export type SocketPackageAlert = {
    name: string;
    version: string;
    key: string;
    type: string;
    blocked: boolean;
    critical: boolean;
    fixable: boolean;
    raw: CompactSocketArtifactAlert;
    upgradable: boolean;
};
export type AlertsByPkgId = Map<string, SocketPackageAlert[]>;
export type RiskCounts = {
    critical: number;
    high: number;
    middle: number;
    low: number;
};
export type AlertIncludeFilter = {
    actions?: ALERT_ACTION[] | undefined;
    blocked?: boolean | undefined;
    critical?: boolean | undefined;
    cve?: boolean | undefined;
    existing?: boolean | undefined;
    unfixable?: boolean | undefined;
    upgradable?: boolean | undefined;
};
export type AddArtifactToAlertsMapOptions = {
    consolidate?: boolean | undefined;
    include?: AlertIncludeFilter | undefined;
    overrides?: {
        [key: string]: string;
    } | undefined;
    spinner?: Spinner | undefined;
};
export declare function addArtifactToAlertsMap<T extends AlertsByPkgId>(artifact: CompactSocketArtifact, alertsByPkgId: T, options?: AddArtifactToAlertsMapOptions | undefined): Promise<T>;
export declare function alertsHaveBlocked(alerts: SocketPackageAlert[]): boolean;
export declare function alertsHaveSeverity(alerts: SocketPackageAlert[], severity: `${keyof typeof ALERT_SEVERITY}`): boolean;
export declare function alertSeverityComparator(a: SocketPackageAlert, b: SocketPackageAlert): number;
export declare function getAlertSeverityOrder(alert: SocketPackageAlert): number;
export declare function getAlertsSeverityOrder(alerts: SocketPackageAlert[]): number;
export type CveExcludeFilter = {
    upgradable?: boolean | undefined;
};
export type CveInfoByAlertKey = Map<string, {
    firstPatchedVersionIdentifier: string;
    vulnerableVersionRange: string;
}>;
export type CveInfoByPkgName = Map<string, CveInfoByAlertKey>;
export type GetCveInfoByPackageOptions = {
    exclude?: CveExcludeFilter | undefined;
    limit?: number | undefined;
};
export declare function getCveInfoFromAlertsMap(alertsMap: AlertsByPkgId, options_?: GetCveInfoByPackageOptions | undefined): CveInfoByPkgName | null;
export declare function getSeverityLabel(severity: `${keyof typeof ALERT_SEVERITY}`): string;
export type LogAlertsMapOptions = {
    hideAt?: `${keyof typeof ALERT_SEVERITY}` | 'none' | undefined;
    output?: NodeJS.WriteStream | undefined;
};
export declare function logAlertsMap(alertsMap: AlertsByPkgId, options: LogAlertsMapOptions): void;
//# sourceMappingURL=socket-package-alert.d.mts.map